@@ -1,6 +1,6 @@
 /*
  * Ncview by David W. Pierce.  A visual netCDF file viewer.
- * Copyright (C) 1993 through 2010 David W. Pierce
+ * Copyright (C) 1993 through 2024 David W. Pierce
  *
  * This program  is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, Version 3, as 
@@ -16,9 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  * David W. Pierce
- * 6259 Caminito Carrena
- * San Diego, CA  92122
- * pierce@cirrus.ucsd.edu
+ * davidwilliampierce@gmail.com
  */
 
 /* define USE_DISK_FONTS */
@@ -149,6 +147,10 @@ void cbar_make( int width, int height, int n_extra_colors, float user_min, float
 			normval = sqrt(normval);
 			normval = sqrt(normval);
 			}
+		else if( transform == TRANSFORM_CENTER ) {
+			normval = atan( (normval - 0.5)*8.0 );
+			normval = normval/3.1415926536 + 0.5;
+			}
 
 		if( options.invert_colors )
 			normval = 1. - normval;
